==> xjadeo_0.4.7.orig.tar.gz: xjadeo-0.4.7/src/qt-gui/qjadeo_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>ImportDialog</name>
    <message>
        <source>Import - Convert Video File</source>
        <translation>Importer - Convertir Fichier Video</translation>
    </message>
    <message>
        <source>Video File</source>
        <translation>Fichier Video</translation>
    </message>
    <message>
        <source>Source:</source>
        <translation>Source:</translation>
    </message>
    <message>
        <source>File Info:</source>
        <translation>Info Fichier:</translation>
    </message>
    <message>
        <source>Destination:</source>
        <translation>Destination:</translation>
    </message>
    <message>
        <source>Encoder Settings</source>
        <translation>Paramètres de l&apos;Encodeur</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Largeur:</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Echelle</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Hauteur:</translation>
    </message>
    <message>
        <source>Break Aspect Ratio</source>
        <translation>Casser le Ratio d&apos;Aspect</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>24</source>
        <translation>24</translation>
    </message>
    <message>
        <source>25</source>
        <translation>25</translation>
    </message>
    <message>
        <source>29.97</source>
        <translation>29.97</translation>
    </message>
    <message>
        <source>30</source>
        <translation>30</translation>
    </message>
    <message>
        <source>Resample</source>
        <translation>Rééchantillonner</translation>
    </message>
    <message>
        <source>extra mencoder options</source>
        <translation>options supplémentaires mencoder</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
</context>
<context>
    <name>ImportProgress</name>
    <message>
        <source>Transcoding Video File</source>
        <translation>Transcodage du Fichier Video</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>qjadeo</source>
        <translation>qjadeo</translation>
    </message>
    <message>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <source>Frame offset</source>
        <translation>Décalage de trame</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>&amp;Sync</source>
        <translation>&amp;Syncro</translation>
    </message>
    <message>
        <source>&amp;Zoom</source>
        <translation>&amp;Zoom</translation>
    </message>
    <message>
        <source>&amp;OSD</source>
        <translation>&amp;Affichage</translation>
    </message>
    <message>
        <source>&amp;Seek</source>
        <translation>&amp;Suivre</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Ouvrir...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>&amp;Close xjadeo and Exit</source>
        <translation>&amp;Fermer xjadeo et Quitter</translation>
    </message>
    <message>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;À propos</translation>
    </message>
    <message>
        <source>ActionGroup</source>
        <translation>GroupeAction</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Sync</translation>
    </message>
    <message>
        <source>JACK Transport</source>
        <translation>Transport JACK</translation>
    </message>
    <message>
        <source>MTC</source>
        <translation>MTC</translation>
    </message>
    <message>
        <source>off</source>
        <translation>éteinte</translation>
    </message>
    <message>
        <source>off (slider)</source>
        <translation>éteinte (glissière)</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <source>50%</source>
        <translation>50%</translation>
    </message>
    <message>
        <source>100%</source>
        <translation>100%</translation>
    </message>
    <message>
        <source>200%</source>
        <translation>200%</translation>
    </message>
    <message>
        <source>Maximize</source>
        <translation>Maximiser</translation>
    </message>
    <message>
        <source>Frame number</source>
        <translation>Numéro de Trame</translation>
    </message>
    <message>
        <source>SMTPE</source>
        <translation>SMPTE</translation>
    </message>
    <message>
        <source>Font...</source>
        <translation>Police...</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importer</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>&amp;Importer</translation>
    </message>
    <message>
        <source>Convert video files.</source>
        <translation>Converti des fichiers vidéo.</translation>
    </message>
    <message>
        <source>Configure qjadeo</source>
        <translation>Configurer qjadeo</translation>
    </message>
    <message>
        <source>&amp;Configure qjadeo</source>
        <translation>&amp;Configurer qjadeo</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Déconnecter</translation>
    </message>
    <message>
        <source>Disconnect and &amp;Exit</source>
        <translation>Déconnecter et &amp;Quitter</translation>
    </message>
    <message>
        <source>to any frame</source>
        <translation>à n&apos;importe quelle trame</translation>
    </message>
    <message>
        <source>keyframes only</source>
        <translation>seulement aux images clef</translation>
    </message>
    <message>
        <source>continuously</source>
        <translation>continuellement</translation>
    </message>
</context>
<context>
    <name>PrefDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Paramètres généraux</translation>
    </message>
    <message>
        <source>Midi port (MTC):</source>
        <translation>Port Midi (MTC):</translation>
    </message>
    <message>
        <source>xjadeo/xjremote executable:</source>
        <translation>Exécutable xjadeo/xjremote:</translation>
    </message>
    <message>
        <source>xjinfo executable:</source>
        <translation>Exécutable xjinfo:</translation>
    </message>
    <message>
        <source>mencoder executable:</source>
        <translation>Exécutable mencoder:</translation>
    </message>
    <message>
        <source>Import Settings</source>
        <translation>Paramètres d&apos;Importation</translation>
    </message>
    <message>
        <source>Import to Codec:</source>
        <translation>Codec:</translation>
    </message>
    <message>
        <source>mpeg4</source>
        <translation>mpeg4</translation>
    </message>
    <message>
        <source>mjpeg</source>
        <translation>mjpeg</translation>
    </message>
    <message>
        <source>msmpeg4</source>
        <translation>msmpeg4</translation>
    </message>
    <message>
        <source>mpeg1video</source>
        <translation>mpeg1video</translation>
    </message>
    <message>
        <source>mpeg2video</source>
        <translation>mpeg2video</translation>
    </message>
    <message>
        <source>mencoder options:</source>
        <translation>Options de mencoder:</translation>
    </message>
    <message>
        <source>Default Import Destination Path:</source>
        <translation>Chemin de destination par défaut:</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
</context>
</TS>

==> xjadeo_0.4.13.orig.tar.gz: xjadeo-0.4.13/src/qt-gui/qjadeo_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>ImportDialog</name>
    <message>
        <source>Import - Convert Video File</source>
        <translation>Importer - Convertir Fichier Video</translation>
    </message>
    <message>
        <source>Video File</source>
        <translation>Fichier Video</translation>
    </message>
    <message>
        <source>Source:</source>
        <translation>Source:</translation>
    </message>
    <message>
        <source>File Info:</source>
        <translation>Info Fichier:</translation>
    </message>
    <message>
        <source>Destination:</source>
        <translation>Destination:</translation>
    </message>
    <message>
        <source>Encoder Settings</source>
        <translation>Paramètres de l&apos;Encodeur</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Largeur:</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Echelle</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Hauteur:</translation>
    </message>
    <message>
        <source>Break Aspect Ratio</source>
        <translation>Casser le Ratio d&apos;Aspect</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>24</source>
        <translation>24</translation>
    </message>
    <message>
        <source>25</source>
        <translation>25</translation>
    </message>
    <message>
        <source>29.97</source>
        <translation>29.97</translation>
    </message>
    <message>
        <source>30</source>
        <translation>30</translation>
    </message>
    <message>
        <source>Resample</source>
        <translation>Rééchantillonner</translation>
    </message>
    <message>
        <source>extra mencoder options</source>
        <translation>options supplémentaires mencoder</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
</context>
<context>
    <name>ImportProgress</name>
    <message>
        <source>Transcoding Video File</source>
        <translation>Transcodage du Fichier Video</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>qjadeo</source>
        <translation>qjadeo</translation>
    </message>
    <message>
        <source>screen updates per sec.</source>
        <translation>Fréquence de rafraîchissement d'écran:</translation>
    </message>
    <message>
        <source>time offset in video-frames:</source>
        <translation>Décalage dans les trames vidéo:</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>&amp;Sync</source>
        <translation>&amp;Syncro</translation>
    </message>
    <message>
        <source>&amp;Zoom</source>
        <translation>&amp;Zoom</translation>
    </message>
    <message>
        <source>&amp;OSD</source>
        <translation>&amp;Affichage</translation>
    </message>
    <message>
        <source>&amp;Seek</source>
        <translation>&amp;Suivre</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Ouvrir...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>&amp;Close xjadeo and Exit</source>
        <translation>&amp;Fermer xjadeo et Quitter</translation>
    </message>
    <message>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;À propos</translation>
    </message>
    <message>
        <source>ActionGroup</source>
        <translation>GroupeAction</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Sync</translation>
    </message>
    <message>
        <source>JACK Transport</source>
        <translation>Transport JACK</translation>
    </message>
    <message>
        <source>MTC (ALSA SEQ)</source>
        <translation>MTC (ALSA SEQ)</translation>
    </message>
    <message>
        <source>MTC (JACK MIDI)</source>
        <translation>MTC (JACK MIDI)</translation>
    </message>
    <message>
        <source>off</source>
        <translation>éteinte</translation>
    </message>
    <message>
        <source>off (slider)</source>
        <translation>éteinte (glissière)</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <source>50%</source>
        <translation>50%</translation>
    </message>
    <message>
        <source>100%</source>
        <translation>100%</translation>
    </message>
    <message>
        <source>200%</source>
        <translation>200%</translation>
    </message>
    <message>
        <source>Maximize</source>
        <translation>Maximiser</translation>
    </message>
    <message>
        <source>Frame number</source>
        <translation>Numéro de Trame</translation>
    </message>
    <message>
        <source>Box</source>
        <translation>Cadre</translation>
    </message>
    <message>
        <source>SMPTE</source>
        <translation>SMPTE</translation>
    </message>
    <message>
        <source>Font...</source>
        <translation>Police...</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importer</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>&amp;Importer</translation>
    </message>
    <message>
        <source>Convert video files.</source>
        <translation>Converti des fichiers vidéo.</translation>
    </message>
    <message>
        <source>Configure qjadeo</source>
        <translation>Configurer qjadeo</translation>
    </message>
    <message>
        <source>&amp;Configure qjadeo</source>
        <translation>&amp;Configurer qjadeo</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Déconnecter</translation>
    </message>
    <message>
        <source>Disconnect and &amp;Exit</source>
        <translation>Déconnecter et &amp;Quitter</translation>
    </message>
    <message>
        <source>to any frame</source>
        <translation>à n&apos;importe quelle trame</translation>
    </message>
    <message>
        <source>keyframes only</source>
        <translation>seulement aux images clef</translation>
    </message>
    <message>
        <source>continuously</source>
        <translation>continuellement</translation>
    </message>
</context>
<context>
    <name>PrefDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Paramètres généraux</translation>
    </message>
    <message>
        <source>Autoconnect ALSA Midi port (MTC):</source>
        <translation>Se connecter automatiquement ce port ALSA Midi (MTC):</translation>
    </message>
    <message>
        <source>Autoconnect JACK Midi port (MTC):</source>
        <translation>Se connecter automatiquement ce port JACK Midi (MTC):</translation>
    </message>
    <message>
        <source>xjadeo/xjremote executable:</source>
        <translation>Exécutable xjadeo/xjremote:</translation>
    </message>
    <message>
        <source>xjinfo executable:</source>
        <translation>Exécutable xjinfo:</translation>
    </message>
    <message>
        <source>mencoder executable:</source>
        <translation>Exécutable mencoder:</translation>
    </message>
    <message>
        <source>Import Settings</source>
        <translation>Paramètres d&apos;Importation</translation>
    </message>
    <message>
        <source>Import to Codec:</source>
        <translation>Codec:</translation>
    </message>
    <message>
        <source>mpeg4</source>
        <translation>mpeg4</translation>
    </message>
    <message>
        <source>mjpeg</source>
        <translation>mjpeg</translation>
    </message>
    <message>
        <source>msmpeg4</source>
        <translation>msmpeg4</translation>
    </message>
    <message>
        <source>mpeg1video</source>
        <translation>mpeg1video</translation>
    </message>
    <message>
        <source>mpeg2video</source>
        <translation>mpeg2video</translation>
    </message>
    <message>
        <source>mencoder options:</source>
        <translation>Options de mencoder:</translation>
    </message>
    <message>
        <source>Default Import Destination Path:</source>
        <translation>Chemin de destination par défaut:</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
</context>
</TS>
